==> flulm_auth-1.1.5.tar.gz: lib/src/utils/constant.dart <==
import 'dart:convert';

import 'package:flutter/cupertino.dart';
import 'package:flutter/foundation.dart';
import 'package:webview_flutter/webview_flutter.dart';
import 'package:url_launcher/url_launcher.dart';

class Constant {
  static const bool isDebug =  true;
  static const double maxH5Width = 2000.0;

  static final String userAgent = "Mozilla/5.0 (Linux; " +
      defaultTargetPlatform.toString() +
      " 6.0; Nexus 5 Build/MRA58N) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/62.0.3202.94 Mobile Safari/537.36";

  static final String userAgentSuffix =
      userAgent + " aochuang flutter-lemasdk lang-";

  //js注册 channel
  static JavascriptChannel alertJavascriptChannel(
      dynamic dispatchJs(String method, Map<String, dynamic> json)) {
    return JavascriptChannel(
        name: 'FlutterSDK',
        onMessageReceived: (JavascriptMessage message) {
          debugPrint("FlutterSDK->" + message.message);
          Map<String, dynamic> json = jsonDecode(message.message);
          if("openSystemWeb" == json['method']){//打开系统浏览器
            launch(json['data']);
          }else{
            var data = json['data'];
            if(data is String){
              data = jsonDecode(data);
            }
            dispatchJs(json['method'], data);
          }
        });
  }

  //获取PAD适配的宽度，H5无法适配PAD
  static double getResetWidth(BuildContext context) {
    double width = MediaQuery.of(context).size.width;
    if (width > maxH5Width) {
      return maxH5Width;
    }
    return width;
  }
}

==> flulm_auth-2.1.0.tar.gz: lib/src/utils/constant.dart <==
import 'dart:convert';

import 'package:flutter/cupertino.dart';
import 'package:flutter/foundation.dart';
import 'package:webview_flutter/webview_flutter.dart';
import 'package:url_launcher/url_launcher.dart';

class Constant {
  static const bool isDebug =  true;
  static const double maxH5Width = 2000.0;

  static final String userAgent = "Mozilla/5.0 (Linux; " +
      defaultTargetPlatform.toString() +
      " 6.0; Nexus 5 Build/MRA58N) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/62.0.3202.94 Mobile Safari/537.36";

  static final String userAgentSuffix =
      userAgent + " aochuang flutter-lemasdk lang-";

  //js注册 channel
  static JavascriptChannel alertJavascriptChannel(
      dynamic dispatchJs(String? method, Map<String, dynamic>? json)) {
    return JavascriptChannel(
        name: 'FlutterSDK',
        onMessageReceived: (JavascriptMessage message) {
          debugPrint("FlutterSDK->" + message.message);
          Map<String, dynamic> json = jsonDecode(message.message);
          if("openSystemWeb" == json['method']){//打开系统浏览器
            launch(json['data']);
          }else{
            var data = json['data'];
            if(data is String){
              data = jsonDecode(data);
            }
            dispatchJs(json['method'], data);
          }
        });
  }

  //获取PAD适配的宽度，H5无法适配PAD
  static double getResetWidth(BuildContext context) {
    double width = MediaQuery.of(context).size.width;
    if (width > maxH5Width) {
      return maxH5Width;
    }
    return width;
  }
}
